@@ -1,8 +1,8 @@
 # $File: //member/autrijus/Locale-Maketext-Lexicon/lib/Locale/Maketext/Lexicon/Gettext.pm $ $Author: autrijus $
-# $Revision: #21 $ $Change: 8407 $ $DateTime: 2003/10/13 20:20:07 $
+# $Revision: #23 $ $Change: 9216 $ $DateTime: 2003/12/08 18:41:04 $
 
 package Locale::Maketext::Lexicon::Gettext;
-$Locale::Maketext::Lexicon::Gettext::VERSION = '0.08';
+$Locale::Maketext::Lexicon::Gettext::VERSION = '0.10';
 
 use strict;
 
@@ -88,7 +88,8 @@ sub parse {
     $InputEncoding = $OutputEncoding = $DoEncoding = undef;
 
     use Carp;
-    Carp::cluck " is happy\n" unless defined $_[0];
+    Carp::cluck "Undefined source called\n" unless defined $_[0];
+
     # Check for magic string of MO files
     return parse_mo(join('', @_))
 	if ($_[0] =~ /^\x95\x04\x12\xde/ or $_[0] =~ /^\xde\x12\x04\x95/);
@@ -136,8 +137,10 @@ sub parse_metadata {
 	    ($1 eq 'Content-Type') ? do {
 		my $enc = $2;
 		if ($enc =~ /\bcharset=\s*([-\w]+)/i) {
-		    $InputEncoding = $1;
-		    $OutputEncoding = Locale::Maketext::Lexicon::option('encoding');
+		    $InputEncoding = $1 || '';
+		    $OutputEncoding = Locale::Maketext::Lexicon::option('encoding') || '';
+		    $InputEncoding = 'utf8' if $InputEncoding =~ /^utf-?8$/i;
+		    $OutputEncoding = 'utf8' if $OutputEncoding =~ /^utf-?8$/i;
 		    if ( Locale::Maketext::Lexicon::option('decode') and
 			(!$OutputEncoding or $InputEncoding ne $OutputEncoding)) {
 			require Encode::compat if $] < 5.007001;
@@ -154,15 +157,25 @@ sub parse_metadata {
 sub transform {
     my $str = shift;
 
-    $str = Encode::decode($InputEncoding, $str) if $DoEncoding and $InputEncoding;
+    if ($DoEncoding and $InputEncoding) {
+	$str = ($InputEncoding eq 'utf8')
+	    ? Encode::decode_utf8($str)
+	    : Encode::decode($InputEncoding, $str)
+    }
+
     $str =~ s/\\([0x]..|c?.)/qq{"\\$1"}/eeg;
-    $str =~ s/[~\[\]]/~$&/g;
+    $str =~ s/([~\[\]])/~$1/g;
     $str =~ s/(?<![%\\])%([A-Za-z#*]\w*)\(([^\)]*)\)/[$1,~~~$2~~~]/g;
     $str = join('', map {
 	/^~~~.*~~~$/ ? unescape(substr($_, 3, -3)) : $_
     } split(/(~~~.*?~~~)/, $str));
     $str =~ s/(?<![%\\])%(\d+|\*)/\[_$1]/g;
-    $str = Encode::encode($OutputEncoding, $str) if $DoEncoding and $OutputEncoding;
+
+    if ($DoEncoding and $OutputEncoding) {
+	$str = ($OutputEncoding eq 'utf8')
+	    ? Encode::encode_utf8($str)
+	    : Encode::encode($OutputEncoding, $str)
+    }
 
     return $str;
 }
